RoPasswordGenerator

A flutter package that randomly generates password with digits, lowcase characters, upcase characters and special characters.

Usage

final password = RoPasswordGenerator.generate(length: 12, includeUpcaseChars: true, excludeSimiliarChars: false);

Installation

  1. Add the latest version of package to your pubspec.yaml (and rundart pub get):
dependencies:
  ro_password_generator: ^0.0.1
  1. Import the package and use it in your Flutter App.
import 'package:ro_password_generator/ro_password_generator.dart';